@@ -17,7 +17,7 @@
 #include "clock-marshallers.h"
 #include "set-timezone.h"
 
-G_DEFINE_TYPE (ClockLocationTile, clock_location_tile, GTK_TYPE_ALIGNMENT)
+G_DEFINE_TYPE (ClockLocationTile, clock_location_tile, GTK_TYPE_BIN)
 
 enum {
 	TILE_PRESSED,
@@ -44,8 +44,6 @@ typedef struct {
         GtkWidget *current_label;
         GtkWidget *current_marker;
         GtkWidget *current_spacer;
-        GtkSizeGroup *current_group;
-        GtkSizeGroup *button_group;
 
         GtkWidget *weather_icon;
 
@@ -152,16 +150,6 @@ clock_location_tile_finalize (GObject *g_obj)
                 priv->location = NULL;
         }
 
-        if (priv->button_group) {
-                g_object_unref (priv->button_group);
-                priv->button_group = NULL;
-        }
-
-        if (priv->current_group) {
-                g_object_unref (priv->current_group);
-                priv->current_group = NULL;
-        }
-
         G_OBJECT_CLASS (clock_location_tile_parent_class)->finalize (g_obj);
 }
 
@@ -260,12 +248,12 @@ static void
 clock_location_tile_fill (ClockLocationTile *this)
 {
         ClockLocationTilePrivate *priv = PRIVATE (this);
-	GtkWidget *align;
         GtkWidget *strut;
         GtkWidget *box;
-        GtkWidget *alignment;
         GtkWidget *tile;
         GtkWidget *head_section;
+        GtkSizeGroup *current_group;
+        GtkSizeGroup *button_group;
 
         priv->box = gtk_event_box_new ();
 
@@ -277,30 +265,29 @@ clock_location_tile_fill (ClockLocationTile *this)
         g_signal_connect (priv->box, "leave-notify-event",
                           G_CALLBACK (enter_or_leave_tile), this);
 
-        alignment = gtk_alignment_new (0, 0, 1, 0);
-        gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 3, 3, 3, 0);
-
         tile = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+        gtk_widget_set_margin_top (tile, 3);
+        gtk_widget_set_margin_bottom (tile, 3);
+        gtk_widget_set_margin_start (tile, 3);
+
         head_section = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 
         priv->city_label = gtk_label_new (NULL);
-        gtk_misc_set_alignment (GTK_MISC (priv->city_label), 0, 0);
+        gtk_widget_set_margin_end (priv->city_label, 3);
+        gtk_label_set_xalign (GTK_LABEL (priv->city_label), 0);
 
-        align = gtk_alignment_new (0, 0, 0, 0);
-        gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, 0, 3);
-        gtk_container_add (GTK_CONTAINER (align), priv->city_label);
-        gtk_box_pack_start (GTK_BOX (head_section), align, FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (head_section), priv->city_label, FALSE, FALSE, 0);
 
         priv->time_label = gtk_label_new (NULL);
-        gtk_misc_set_alignment (GTK_MISC (priv->time_label), 0, 0);
+        gtk_widget_set_margin_end (priv->time_label, 3);
+        gtk_label_set_yalign (GTK_LABEL (priv->time_label), 0);
 
         priv->weather_icon = gtk_image_new ();
-        align = gtk_alignment_new (0, 0, 0, 0);
-        gtk_container_add (GTK_CONTAINER (align), priv->weather_icon);
+        gtk_widget_set_valign (priv->weather_icon, GTK_ALIGN_START);
 
         box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_box_pack_start (GTK_BOX (head_section), box, FALSE, FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (box), align, FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (box), priv->weather_icon, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (box), priv->time_label, FALSE, FALSE, 0);
 
         priv->current_button = gtk_button_new ();
@@ -313,7 +300,6 @@ clock_location_tile_fill (ClockLocationTile *this)
 				     _("Set location as current location and use its timezone for this computer"));
 
 	priv->current_marker = gtk_image_new_from_icon_name ("go-home", GTK_ICON_SIZE_BUTTON);
-	gtk_misc_set_alignment (GTK_MISC (priv->current_marker), 1.0, 0.5);
 	gtk_widget_set_no_show_all (priv->current_marker, TRUE);
 
 	priv->current_spacer = gtk_event_box_new ();
@@ -324,10 +310,12 @@ clock_location_tile_fill (ClockLocationTile *this)
         gtk_box_pack_start (GTK_BOX (box), priv->current_button, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (box), priv->current_marker, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (box), priv->current_spacer, FALSE, FALSE, 0);
-        priv->button_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
-        gtk_size_group_set_ignore_hidden (priv->button_group, FALSE);
-        gtk_size_group_add_widget (priv->button_group, strut);
-        gtk_size_group_add_widget (priv->button_group, priv->current_button);
+
+        button_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
+        gtk_size_group_set_ignore_hidden (button_group, FALSE);
+        gtk_size_group_add_widget (button_group, strut);
+        gtk_size_group_add_widget (button_group, priv->current_button);
+        g_object_unref (button_group);
 
 	/* 
 	 * Avoid resizing the popup as the tiles display the current marker, 
@@ -338,11 +326,12 @@ clock_location_tile_fill (ClockLocationTile *this)
  	 * (The all have to be shown initially to get the sizes worked out, 
  	 * but they are never visible together). 
 	 */
-        priv->current_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
-        gtk_size_group_set_ignore_hidden (priv->current_group, FALSE);
-        gtk_size_group_add_widget (priv->current_group, priv->current_button);
-        gtk_size_group_add_widget (priv->current_group, priv->current_marker);
-        gtk_size_group_add_widget (priv->current_group, priv->current_spacer);
+        current_group = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
+        gtk_size_group_set_ignore_hidden (current_group, FALSE);
+        gtk_size_group_add_widget (current_group, priv->current_button);
+        gtk_size_group_add_widget (current_group, priv->current_marker);
+        gtk_size_group_add_widget (current_group, priv->current_spacer);
+        g_object_unref (current_group);
 	
 	gtk_widget_show (priv->current_button);
 	gtk_widget_show (priv->current_marker);
@@ -357,8 +346,7 @@ clock_location_tile_fill (ClockLocationTile *this)
         gtk_box_pack_start (GTK_BOX (tile), priv->clock_face, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (tile), head_section, TRUE, TRUE, 0);
 
-        gtk_container_add (GTK_CONTAINER (alignment), tile);
-        gtk_container_add (GTK_CONTAINER (priv->box), alignment);
+        gtk_container_add (GTK_CONTAINER (priv->box), tile);
         gtk_container_add (GTK_CONTAINER (this), priv->box);
 }
 
@@ -400,6 +388,9 @@ clock_needs_label_refresh (ClockLocationTile *this)
 	long offset;
 	gboolean retval;
 
+	if (!priv->last_refresh)
+		return TRUE;
+
         now = clock_location_localtime (priv->location);
 	offset = clock_location_get_offset (priv->location);
 
@@ -699,7 +690,7 @@ update_weather_icon (ClockLocation *loc, GWeatherInfo *info, gpointer data)
 
         if (pixbuf) {
                 gtk_image_set_from_pixbuf (GTK_IMAGE (priv->weather_icon), pixbuf);
-                gtk_alignment_set_padding (GTK_ALIGNMENT (gtk_widget_get_parent (priv->weather_icon)), 0, 0, 0, 6);
+                gtk_widget_set_margin_end (priv->weather_icon, 6);
         }
 }
 
