@@ -71,6 +71,7 @@ G_DEFINE_TYPE (PanelDesktopMenuItem, panel_desktop_menu_item, PANEL_TYPE_IMAGE_M
 struct _PanelPlaceMenuItemPrivate {
 	GtkWidget   *menu;
 	PanelWidget *panel;
+	GSettings   *settings;
 
 	GtkRecentManager *recent_manager;
 
@@ -1262,66 +1263,67 @@ panel_desktop_menu_item_create_menu (PanelDesktopMenuItem *desktop_item,
 }
 
 static void
-panel_place_menu_item_finalize (GObject *object)
+panel_place_menu_item_dispose (GObject *object)
 {
-	PanelPlaceMenuItem *menuitem = (PanelPlaceMenuItem *) object;
+  PanelPlaceMenuItem *menuitem = (PanelPlaceMenuItem *) object;
 
-	if (menuitem->priv->bookmarks_monitor != NULL) {
-		g_file_monitor_cancel (menuitem->priv->bookmarks_monitor);
-		g_object_unref (menuitem->priv->bookmarks_monitor);
-	}
-	menuitem->priv->bookmarks_monitor = NULL;
+  g_clear_object (&menuitem->priv->settings);
 
-	if (menuitem->priv->drive_changed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->drive_changed_id);
-	menuitem->priv->drive_changed_id = 0;
+  if (menuitem->priv->bookmarks_monitor != NULL)
+    {
+      g_file_monitor_cancel (menuitem->priv->bookmarks_monitor);
 
-	if (menuitem->priv->drive_connected_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->drive_connected_id);
-	menuitem->priv->drive_connected_id = 0;
+      g_clear_object (&menuitem->priv->bookmarks_monitor);
+    }
 
-	if (menuitem->priv->drive_disconnected_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->drive_disconnected_id);
-	menuitem->priv->drive_disconnected_id = 0;
+  if (menuitem->priv->drive_changed_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->drive_changed_id);
+  menuitem->priv->drive_changed_id = 0;
 
-	if (menuitem->priv->volume_added_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->volume_added_id);
-	menuitem->priv->volume_added_id = 0;
+  if (menuitem->priv->drive_connected_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->drive_connected_id);
+  menuitem->priv->drive_connected_id = 0;
 
-	if (menuitem->priv->volume_changed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->volume_changed_id);
-	menuitem->priv->volume_changed_id = 0;
+  if (menuitem->priv->drive_disconnected_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->drive_disconnected_id);
+  menuitem->priv->drive_disconnected_id = 0;
 
-	if (menuitem->priv->volume_removed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->volume_removed_id);
-	menuitem->priv->volume_removed_id = 0;
+  if (menuitem->priv->volume_added_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->volume_added_id);
+  menuitem->priv->volume_added_id = 0;
 
-	if (menuitem->priv->mount_added_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->mount_added_id);
-	menuitem->priv->mount_added_id = 0;
+  if (menuitem->priv->volume_changed_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->volume_changed_id);
+  menuitem->priv->volume_changed_id = 0;
 
-	if (menuitem->priv->mount_changed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->mount_changed_id);
-	menuitem->priv->mount_changed_id = 0;
+  if (menuitem->priv->volume_removed_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->volume_removed_id);
+  menuitem->priv->volume_removed_id = 0;
 
-	if (menuitem->priv->mount_removed_id)
-		g_signal_handler_disconnect (menuitem->priv->volume_monitor,
-					     menuitem->priv->mount_removed_id);
-	menuitem->priv->mount_removed_id = 0;
+  if (menuitem->priv->mount_added_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->mount_added_id);
+  menuitem->priv->mount_added_id = 0;
 
-	if (menuitem->priv->volume_monitor != NULL)
-		g_object_unref (menuitem->priv->volume_monitor);
-	menuitem->priv->volume_monitor = NULL;
+  if (menuitem->priv->mount_changed_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->mount_changed_id);
+  menuitem->priv->mount_changed_id = 0;
 
-	G_OBJECT_CLASS (panel_place_menu_item_parent_class)->finalize (object);
+  if (menuitem->priv->mount_removed_id)
+    g_signal_handler_disconnect (menuitem->priv->volume_monitor,
+                                 menuitem->priv->mount_removed_id);
+  menuitem->priv->mount_removed_id = 0;
+
+  g_clear_object (&menuitem->priv->volume_monitor);
+
+  G_OBJECT_CLASS (panel_place_menu_item_parent_class)->dispose (object);
 }
 
 static void
@@ -1335,6 +1337,9 @@ panel_place_menu_item_init (PanelPlaceMenuItem *menuitem)
 	menuitem->priv = PANEL_PLACE_MENU_ITEM_GET_PRIVATE (menuitem);
 
 	settings = g_settings_new (GNOME_NAUTILUS_DESKTOP_SCHEMA);
+
+	menuitem->priv->settings = settings;
+
 	g_signal_connect (settings, "changed::" GNOME_NAUTILUS_DESKTOP_HOME_ICON_NAME_KEY,
 	                  G_CALLBACK (panel_place_menu_item_key_changed), menuitem);
 
@@ -1415,7 +1420,7 @@ panel_place_menu_item_class_init (PanelPlaceMenuItemClass *klass)
 {
 	GObjectClass *gobject_class = (GObjectClass *) klass;
 
-	gobject_class->finalize = panel_place_menu_item_finalize;
+	gobject_class->dispose = panel_place_menu_item_dispose;
 
 	g_type_class_add_private (klass, sizeof (PanelPlaceMenuItemPrivate));
 }
@@ -1440,7 +1445,15 @@ panel_place_menu_item_new (gboolean use_image,
 	icon_name = PANEL_ICON_FOLDER;
 
 	if (in_menubar) {
+		GtkWidget *label;
+		GtkStyleContext *context;
+
 		gtk_menu_item_set_label (GTK_MENU_ITEM (menuitem), name);
+
+		label = gtk_bin_get_child (GTK_BIN (menuitem));
+		context = gtk_widget_get_style_context (label);
+		gtk_style_context_add_class (context, "gp-text-color");
+
 		if (use_image) {
 			GtkIconSize icon_size;
 			GtkWidget *image;
@@ -1488,9 +1501,16 @@ panel_desktop_menu_item_new (gboolean use_image,
 	/* if we're in a menubar, we don't want to use setup_* as it changes
 	 * the size requests and can make the panels bigger than we'd like */
 	if (in_menubar) {
+		GtkWidget *label;
+		GtkStyleContext *context;
+
 		gtk_menu_item_set_label (GTK_MENU_ITEM (menuitem), name);
 		menuitem->priv->icon_size = panel_menu_bar_object_icon_get_size ();
 
+		label = gtk_bin_get_child (GTK_BIN (menuitem));
+		context = gtk_widget_get_style_context (label);
+		gtk_style_context_add_class (context, "gp-text-color");
+
 		if (use_image) {
 			GtkWidget *image;
 			image = gtk_image_new_from_icon_name (icon_name,
