@@ -25,7 +25,6 @@
 
 #include <gtk/gtk.h>
 
-#include "panel-background.h"
 #include "panel-enums.h"
 
 G_BEGIN_DECLS
@@ -51,8 +50,6 @@ typedef struct _PanelToplevelPrivate PanelToplevelPrivate;
 struct _PanelToplevel {
 	GtkWindow              window_instance;
 
-	PanelBackground        background;
-
 	PanelToplevelPrivate  *priv;
 };
 
@@ -149,7 +146,6 @@ PanelAnimationSpeed  panel_toplevel_get_animation_speed    (PanelToplevel
 void                 panel_toplevel_set_enable_buttons     (PanelToplevel       *toplevel,
 							    gboolean             enable_buttons);
 gboolean             panel_toplevel_get_enable_buttons     (PanelToplevel       *toplevel);
-void                 panel_toplevel_update_edges           (PanelToplevel       *toplevel);
 
 gboolean             panel_toplevel_is_last                (PanelToplevel       *toplevel);
 int                  panel_toplevel_get_maximum_size       (PanelToplevel *toplevel);
